Index: chrome/common/chrome_notification_types.h |
diff --git a/chrome/common/chrome_notification_types.h b/chrome/common/chrome_notification_types.h |
index 40d796552f4be082581e43e3cb90cc22223b03dd..002f93fb1ab7ffe810346bbb4e109d5c14c7907f 100644 |
--- a/chrome/common/chrome_notification_types.h |
+++ b/chrome/common/chrome_notification_types.h |
@@ -1097,13 +1097,16 @@ enum NotificationType { |
// Sent each time the InstantController shows the InstantLoader. |
NOTIFICATION_INSTANT_CONTROLLER_SHOWN, |
- // Sent when an Instant preview is committed. The Source is the |
- // TabContents containing the committed preview. There are no details. |
+ // Sent each time the InstantController hides the InstantLoader. |
+ NOTIFICATION_INSTANT_CONTROLLER_HIDDEN, |
+ |
+ // Sent when an Instant preview is committed. The Source is the TabContents |
+ // containing the committed preview. There are no details. |
NOTIFICATION_INSTANT_COMMITTED, |
- // Sent when the instant loader determines whether the page supports the |
- // instant API or not. The details is a boolean indicating if the page |
- // supports instant. The source is not used. |
+ // Sent when the Instant loader determines whether the page supports the |
+ // Instant API or not. The details is a boolean indicating if the page |
+ // supports Instant. The source is not used. |
NOTIFICATION_INSTANT_SUPPORT_DETERMINED, |
// Sent when the CaptivePortalService checks if we're behind a captive portal. |